#include <iostream>
#include <vector>
#include <map>
#include <cmath>
#include <algorithm>
#include <cassert>

using namespace std;
#define ll long long
const ll mod = 1e9 + 7;
const int INF = 1e9 + 10;

inline ll power(ll a, int n) {
    ll cur = 1;
    while (n) {
        if (n & 1) {
            cur = cur * a % mod;
        }
        n >>= 1;
        a = a * a % mod;
    }
    return cur;
}

vector <ll> fact, rfact;
vector <int> blr, bll;
map <int, vector <int>> all;

void build(int n) {
    fact.resize(n + 1, 1);
    rfact.resize(n + 1, 1);
    for (int i = 2; i <= n; ++i) fact[i] = fact[i - 1] * i % mod;
    rfact[n] = power(fact[n], mod - 2);
    for (int i = n - 1; i > 1; --i) rfact[i] = (rfact[i + 1] * (i + 1)) % mod;
}

struct SegTree {
    int len;
    vector <int> t;

    SegTree(int n) {
        len = 1 << (int)ceil(log2(n));
        t.resize(2 * len, INF);
    }

    SegTree() {}

    inline void update(int i, int x) {
        i += len;
        t[i] = x;
        i >>= 1;
        while (i > 0) {
            t[i] = min(t[2 * i], t[2 * i + 1]);
            i >>= 1;
        }
    }

    inline int get_min(int l, int r) {
        l += len;
        r += len;
        int mn = INF;
        while (l <= r) {
            if (l & 1) {
                mn = min(mn, t[l++]);
            }
            if (!(r & 1)) {
                mn = min(mn, t[r--]);
            }
            l >>= 1;
            r >>= 1;
        }
        return mn;
    }
};

struct SegTreeMax {
    int n;
    vector <int> t;

    SegTreeMax(int n, vector <int>& a) : n(n) {
        t.resize(4 * n, -INF);
        build(1, 0, n - 1, a);
    }

    void build(int v, int l, int r, vector <int>& a) {
        if (l == r) {
            t[v] = a[l];
            return;
        }
        int m = (l + r) / 2;
        build(2 * v, l, m, a);
        build(2 * v + 1, m + 1, r, a);
        t[v] = max(t[2 * v], t[2 * v + 1]);
    }

    int first_more(int v, int l, int r, int A, int B, int x) {
        if (l > B || A > r || t[v] <= x) return -1;
        if (l == r) return l;
        int m = (l + r) / 2;
        int ans1 = first_more(2 * v, l, m, A, B, x);
        if (ans1 != -1) return ans1;
        return first_more(2 * v + 1, m + 1, r, A, B, x);
    }

    inline int first_more(int l, int r, int x) {
        return first_more(1, 0, n - 1, l, r, x);
    }

    int last_more(int v, int l, int r, int A, int B, int x) {
        if (l > B || A > r || t[v] <= x) return -1;
        if (l == r) return l;
        int m = (l + r) / 2;
        int ans1 = last_more(2 * v + 1, m + 1, r, A, B, x);
        if (ans1 != -1) return ans1;
        return last_more(2 * v, l, m, A, B, x);
    }

    inline int last_more(int l, int r, int x) {
        return last_more(1, 0, n - 1, l, r, x);
    }
};


struct Fenwick {
    int n;
    vector <int> f;

    Fenwick(int n) : n(n) {
        f.resize(n + 1);
    }

    Fenwick() {}

    inline void add(int i, int x) {
        for (++i; i <= n; i += (i & (-i))) f[i] += x;
    }

    inline int get_pref(int i) {
        int ans = 0;
        for (++i; i > 0; i -= (i & (-i))) ans += f[i];
        return ans;
    }

    inline int get_seg(int l, int r) {
        return get_pref(r) - get_pref(l - 1);
    }
};

inline ll cnk(int n, int k) {
    return fact[n] * rfact[k] % mod * rfact[n - k] % mod;
}

SegTree t;
Fenwick f;

ll ans = 1;
int k;

void calc(int l, int r) {
    int mn = t.get_min(l, r);
    if (mn == INF) return;
    auto it = lower_bound(all[mn].begin(), all[mn].end(), l);
    int ff = INF, ss = -INF;
    while (it != all[mn].end() && *it <= r) {
        int cnt = 0;
        int curl = bll[*it];
        int curr = blr[*it];
        while (it != all[mn].end() && *it <= r && bll[*it] == curl && blr[*it] == curr) {
            ++cnt;
            t.update(*it, INF);
            f.add(*it, -1);
            it++;
        }
        ans = ans * cnk(f.get_seg(curl + 1, curr - 1) + cnt, cnt) % mod;
        calc(curl + 1, curr - 1);
        ff = min(ff, curl - 1);
        ss = curr + 1;
    }
    calc(l, ff);
    calc(ss, r);
}

void solve() {
    int n;
    cin >> n >> k;
    assert(k < INF);
    vector <int> a(n);
    for (int i = 0; i < n; ++i) cin >> a[i];
    for (int i = 0; i < n; ++i) {
        assert(a[i] < INF);
        all[a[i]].push_back(i);
    }
    build(n);
    t = SegTree(n);
    f = Fenwick(n);
    for (int i = 0; i < n; ++i) {
        t.update(i, a[i]);
        f.add(i, 1);
    }
    bll.resize(n, -1);
    blr.resize(n, n);
    SegTreeMax tt(n, a);
    for (int i = 0; i < n; ++i) {
        int lf = tt.last_more(0, i, k - a[i]);
        if (lf == -1) bll[i] = -1;
        else bll[i] = lf;
        int rg = tt.first_more(i + 1, n - 1, k - a[i]);
        if (rg == -1) blr[i] = n;
        else blr[i] = rg;
    }
    calc(0, n - 1);
    cout << ans;
}

void stupid() {
    int n;
    cin >> n >> k;
    vector <int> a(n);
    for (int i = 0; i < n; ++i) cin >> a[i];
    vector <int> p(n);
    for (int i = 1; i <= n; ++i) p[i - 1] = i;
    do {
        bool ok = true;
        for (int i = 0; i < n; ++i) {
            for (int j = i + 1; j < n; ++j) {
                if (a[p[i] - 1] + a[p[j] - 1] > k && p[i] > p[j]) ok = false;
            }
        }
        ans += ok;
    } while (next_permutation(p.begin(), p.end()));
    cout << ans - 1;
}

signed main() {
    if (1) {
        ios_base::sync_with_stdio(false);
        cin.tie(nullptr);
        cout.tie(nullptr);
    }
    if (1) {
        solve();
    } else {
        stupid();
    }
}