//#pragma GCC optimize("Ofast,unroll-loops")
#include <iostream>
#include <vector>
#include <map>
#include <cmath>
#include <algorithm>
#include <set>

using namespace std;
#define ll long long

const ll mod = 1e9 + 7;
const int INF = 2e9 + 10;

inline ll power(ll a, int n) {
    ll cur = 1;
    while (n) {
        if (n & 1) {
            cur = cur * a % mod;
        }
        n >>= 1;
        a = a * a % mod;
    }
    return cur;
}

vector <ll> fact, rfact;
vector <int> blr, bll;
map <int, vector <int>> all;

void build(int n) {
    fact.resize(n + 1, 1);
    rfact.resize(n + 1, 1);
    for (int i = 2; i <= n; ++i) fact[i] = fact[i - 1] * i % mod;
    rfact[n] = power(fact[n], mod - 2);
    for (int i = n - 1; i > 1; --i) rfact[i] = (rfact[i + 1] * (i + 1)) % mod;
}

struct SegTree {
    int len;
    vector <int> t;

    SegTree(int n) {
        len = 1 << (int)ceil(log2(n));
        t.resize(2 * len, INF);
    }

    SegTree() {}

    inline void update(int i, int x) {
        i += len;
        t[i] = x;
        i >>= 1;
        while (i > 0) {
            t[i] = min(t[2 * i], t[2 * i + 1]);
            i >>= 1;
        }
    }

    inline int get_min(int l, int r) {
        l += len;
        r += len;
        int mn = INF;
        while (l <= r) {
            if (l & 1) {
                mn = min(mn, t[l++]);
            }
            if (!(r & 1)) {
                mn = min(mn, t[r--]);
            }
            l >>= 1;
            r >>= 1;
        }
        return mn;
    }
};

struct Fenwick {
    int n;
    vector <int> f;

    Fenwick(int n) : n(n) {
        f.resize(n + 1);
    }

    Fenwick() {}

    inline void add(int i, int x) {
        for (++i; i <= n; i += (i & (-i))) f[i] += x;
    }

    inline int get_pref(int i) {
        int ans = 0;
        for (++i; i > 0; i -= (i & (-i))) ans += f[i];
        return ans;
    }

    inline int get_seg(int l, int r) {
        if (l > r) return 0;
        return get_pref(r) - get_pref(l - 1);
    }
};

inline ll cnk(int n, int k) {
    return fact[n] * rfact[k] % mod * rfact[n - k] % mod;
}

SegTree t;
Fenwick f;

ll ans = 1;
int k;

void calc(int l, int r) {
    int mn = t.get_min(l, r);
    if (mn == INF) return;
    auto it = lower_bound(all[mn].begin(), all[mn].end(), l);
    int prv = l;
    while (it != all[mn].end() && *it <= r) {
        int cnt = 0;
        int curl = bll[*it];
        int curr = blr[*it];
        while (it != all[mn].end() && *it <= r && bll[*it] == curl && blr[*it] == curr) {
            ++cnt;
            t.update(*it, INF);
            f.add(*it, -1);
            it++;
        }
        ans = ans * cnk(f.get_seg(curl + 1, curr - 1) + cnt, cnt) % mod;
        calc(curl + 1, curr - 1);
        calc(prv, curl - 1);
        prv = curr + 1;
    }
    calc(prv, r);
}

void solve() {
    int n;
    cin >> n >> k;
    vector <int> a(n);
    for (int i = 0; i < n; ++i) cin >> a[i];
    for (int i = 0; i < n; ++i) {
        all[a[i]].push_back(i);
    }
    build(n);
    t = SegTree(n);
    f = Fenwick(n);
    for (int i = 0; i < n; ++i) {
        t.update(i, a[i]);
        f.add(i, 1);
    }
    bll.resize(n, -1);
    blr.resize(n, n);
    vector <int> st;
    for (int i = 0; i < n; ++i) {
        if (st.empty() || a[st[0]] + a[i] <= k) {
            while (!st.empty() && a[st.back()] <= a[i]) st.pop_back();
            st.push_back(i);
            continue;
        }
        int l = 0, r = (int)st.size();
        while (r - l > 1) {
            int m = (l + r) / 2;
            if (a[st[m]] + a[i] > k) l = m;
            else r = m;
        }
        bll[i] = st[l];
        while (!st.empty() && a[st.back()] <= a[i]) st.pop_back();
        st.push_back(i);
    }
    st.clear();
    for (int i = n - 1; i >= 0; --i) {
        if (st.empty() || a[st[0]] + a[i] <= k) {
            while (!st.empty() && a[st.back()] <= a[i]) st.pop_back();
            st.push_back(i);
            continue;
        }
        int l = 0, r = (int)st.size();
        while (r - l > 1) {
            int m = (l + r) / 2;
            if (a[st[m]] + a[i] > k) l = m;
            else r = m;
        }
        blr[i] = st[l];
        while (!st.empty() && a[st.back()] <= a[i]) st.pop_back();
        st.push_back(i);
    }
    calc(0, n - 1);
    cout << ans;
}

void stupid() {
    int n;
    cin >> n >> k;
    vector <int> a(n);
    for (int i = 0; i < n; ++i) cin >> a[i];
    vector <int> p(n);
    for (int i = 1; i <= n; ++i) p[i - 1] = i;
    set <vector <int>> flex;
    do {
        bool ok = true;
        for (int i = 0; i < n; ++i) {
            for (int j = i + 1; j < n; ++j) {
                if (a[p[i] - 1] + a[p[j] - 1] > k && p[i] > p[j]) ok = false;
            }
        }
        if (ok) {
            vector <int> arr(n);
            for (int i = 0; i < n; ++i) arr[i] = a[p[i] - 1];
            flex.insert(arr);
        }
    } while (next_permutation(p.begin(), p.end()));
    cout << (int)flex.size();
}

signed main() {
    if (1) {
        ios_base::sync_with_stdio(false);
        cin.tie(nullptr);
        cout.tie(nullptr);
    }
    if (1) {
        solve();
    } else {
        stupid();
    }
}