#include <iostream>
#include <vector>
#include <algorithm>
#include <cassert>
#include <numeric>

int const nmax = 300000;
int const modulo = 1000000007;
int const lgmax = 20;
int fact[1 + nmax];

void precompute() {
  fact[0] = 1;
  for(int i = 1;i <= nmax; i++)
    fact[i] = 1LL * fact[i - 1] * i % modulo;
}

int lgpow(int a, int b) {
  if(b == 0)
    return 1;
  else {
    int result = lgpow(a, b / 2);
    if(b % 2 == 0)
      return 1LL * result * result % modulo;
    else
      return 1LL * result * result % modulo * a % modulo;
  }
}
int inverse(int number) {
  return lgpow(number, modulo - 2);
}
int comb(int n, int k) {
  return 1LL * fact[n] * inverse(1LL * fact[k] * fact[n - k] % modulo) % modulo;
}
int v[5 + nmax];
int rmq[1 + lgmax][1 + nmax];

void computermq(int n) {
  for(int i = 1; i <= n; i++)
    rmq[0][i] = v[i];
  for(int h = 1;h <= lgmax; h++)
    for(int i = 1;i <= n - (1 << h) + 1; i++)
      rmq[h][i] = std::max(rmq[h - 1][i], rmq[h - 1][i + (1 << (h - 1))]);
}

int extract(int x, int y) {
  int h = 31 - __builtin_clz(y - x + 1);
  return std::max(rmq[h][x], rmq[h][y - (1 << h) + 1]);
}

class FenwickTree{
  private:
    std::vector<int> aib;
    int n;
  public:
    FenwickTree(int n_) {
      n = n_;
      aib.resize(1 + n);
    }
    void update(int pos, int val) {
      for(int x = pos; x <= n; x += (x ^ (x & (x - 1))))
        aib[x] += val;
    }
    int query(int pos) {
      int result = 0;
      for(int x = pos; 0 < x; x = (x & (x - 1)))
        result += aib[x];
      return result;
    }
};

int main() {
  std::ios::sync_with_stdio(0);
  std::cin.tie(0);

  precompute();
  int n, k;
  std::cin >> n >> k;
  for(int i = 1;i <= n; i++)
    std::cin >> v[i];
  computermq(n);
  std::vector<int> id(n);
  std::iota(id.begin(), id.end(), 1);
  std::sort(id.begin(), id.end(), 
      [&](int x, int y) {
      if(v[x] != v[y])
      return v[x] < v[y];
      else
      return x < y;
      });
  int result = 1;
  int lastx = 0, lasty = 0;

  FenwickTree aib(n);
  for(int i = 1;i <= n; i++)
    aib.update(i, 1);

  int ptr = 0;
  while(ptr < id.size()) {
    int pos = id[ptr];
    lastx = pos;
    lasty = pos;
    for(int jump = (1 << 20); 0 < jump; jump /= 2)
      if(1 <= lastx - jump && v[pos] + extract(lastx - jump, pos) <= k)
        lastx -= jump;
    for(int jump = (1 << 20); 0 < jump; jump /= 2)
      if(lasty + jump <= n && v[pos] + extract(pos, lasty + jump) <= k)
        lasty += jump;
    
    int active = aib.query(lasty) - aib.query(lastx - 1);
    int chose = 0;
    while(ptr < id.size() && v[id[ptr]] == v[pos] && lastx <= id[ptr] && id[ptr] <= lasty) {
      aib.update(id[ptr], -1);
      ptr++;
      chose++;
    }
    result = 1LL * result * comb(active, chose) % modulo;
  }
  std::cout << result << '\n';
  return 0;
}
