#include <iostream>
#include <vector>
#include <algorithm>
#include <cassert>
#include <numeric>
#include <set>

int const nmax = 300000;
int const modulo = 1000000007;
int const lgmax = 20;
int fact[1 + nmax], invfact[1 + nmax];

int lgpow(int a, int b) {
  if(b == 0)
    return 1;
  else {
    int result = lgpow(a, b / 2);
    if(b % 2 == 0)
      return 1LL * result * result % modulo;
    else
      return 1LL * result * result % modulo * a % modulo;
  }
}
int inverse(int number) {
  return lgpow(number, modulo - 2);
}

void precompute() {
  fact[0] = 1;
  for(int i = 1;i <= nmax; i++)
    fact[i] = 1LL * fact[i - 1] * i % modulo;
  invfact[nmax] = inverse(fact[nmax]);
  for(int i = nmax; 1 <= i; i--)
    invfact[i - 1] = 1LL * invfact[i] * i % modulo;
}
int comb(int n, int k) {
  return 1LL * fact[n] * invfact[k] % modulo * invfact[n - k] % modulo;
}
int v[5 + nmax];

class FenwickTree{
  private:
    std::vector<int> aib;
    int n;
  public:
    FenwickTree(int n_) {
      n = n_;
      aib.resize(1 + n);
    }
    void update(int pos, int val) {
      for(int x = pos; x <= n; x += (x ^ (x & (x - 1))))
        aib[x] += val;
    }
    int query(int pos) {
      int result = 0;
      for(int x = pos; 0 < x; x = (x & (x - 1)))
        result += aib[x];
      return result;
    }
};

int main() {
  std::ios::sync_with_stdio(0);
  std::cin.tie(0);

  precompute();
  int n, k;
  std::cin >> n >> k;
  for(int i = 1;i <= n; i++)
    std::cin >> v[i];
  std::vector<int> id(n);
  std::iota(id.begin(), id.end(), 1);
  std::sort(id.begin(), id.end(), 
      [&](int x, int y) {
      if(v[x] != v[y])
      return v[x] < v[y];
      else
      return x < y;
      });
  int result = 1;
  int lastx = 0, lasty = 0;

  FenwickTree aib(n);
  for(int i = 1;i <= n; i++)
    aib.update(i, 1);

  int ptr = 0, othptr = id.size() - 1;
  std::set<int> myset;
  myset.insert(0);
  myset.insert(n + 1);

  while(ptr < id.size()) {
    int pos = id[ptr];
    while(0 <= othptr && k < v[id[othptr]] + v[pos])
      myset.insert(id[othptr--]);

    std::set<int>::iterator it = myset.lower_bound(pos);
    lasty = (*it) - 1;
    it--;
    lastx = (*it) + 1;
    if(lastx <= pos && pos <= lasty) { 
      int active = aib.query(lasty) - aib.query(lastx - 1);
      int chose = 0;
      while(ptr < id.size() && v[id[ptr]] == v[pos] && lastx <= id[ptr] && id[ptr] <= lasty) {
        aib.update(id[ptr], -1);
        ptr++;
        chose++;
      }
      result = 1LL * result * comb(active, chose) % modulo;
    } else
      break;
  }
  std::cout << result << '\n';
  return 0;
}
