#include <bits/stdc++.h>

using namespace std;

const int BASE = 1e9 + 7;

int mult(int x, int y) {
    return (long long)x*y % BASE;
}
int bin_pow(int x, int y) {
    int res = 1;
    while (y) {
        if (y & 1) res = mult(res, x);
        x = mult(x, x);
        y >>= 1;
    }
    return res;
}
int inverse(int x) {
    return bin_pow(x, BASE-2);
}
vector<int> factorial;
int combi(int n, int r, bool repeats = false) {
    if (repeats) return combi(n+r-1, r);
    return (long long)factorial[n] * inverse(factorial[r]) % BASE * inverse(factorial[n-r]) % BASE;
}

void update(vector<int> &fenwick, int index, int value) {
    while (index < (int)fenwick.size()) {
        fenwick[index] += value;
        index += index & -index;
    }
}
int read(vector<int> &fenwick, int index) {
    int sum = 0;
    while (index > 0) {
        sum += fenwick[index];
        index -= index & -index;
    }
    return sum;
}

int main() {
    ios_base::sync_with_stdio(0); cin.tie(0); cout.tie(0);
    int n, k; cin >> n >> k;

    // precalculate factorials
    factorial.resize(n+6);
    factorial[0] = 1;
    for (int i = 1; i <= n+5; ++i) factorial[i] = mult(factorial[i-1], i);


    vector<int> w(n+3, k);
    for (int i = 2; i <= n+1; ++i) cin >> w[i];
    n = n+2;

    vector<pair<int, int>> loc(n); // location
    for (int i = 1; i <= n; ++i) loc[i-1] = {w[i], i};
    sort(loc.begin(), loc.end(), [](const pair<int, int> &a, const pair<int, int> &b) {
         return a.first > b.first || a.first == b.first && a.second < b.second;
    });

    vector<int> fFreq(1+n), fBlockFreq(1+n); // fenwick trees
    for (int i = 1; i <= n; ++i) update(fBlockFreq, i, +1);

    int ans = 1;
    for (int i = 0, j = (int)loc.size()-1; (int)i < loc.size(); ++i) {
        auto [x, pos] = loc[i];

        // remove blocks that do not apply to this value
        while (j >= 0 && x+loc[j].first <= k) {
            update(fBlockFreq, loc[j].second, -1);
            --j;
        }

        if (2*x > k) {
            update(fFreq, pos, +1);
            continue;
        }

        // find previous block using fBlockFreq
        int l = 1, r = pos;
        while (l+1 < r) {
            int m = (l+r)/2;
            if (read(fBlockFreq, pos) - read(fBlockFreq, m-1)) l = m;
            else r = m;
        }
        int prevB = l;

        // find next block using fBlockFreq
        l = pos, r = n;
        while (l+1 < r) {
            int m = (l+r)/2;
            if (read(fBlockFreq, m) - read(fBlockFreq, pos)) r = m;
            else l = m;
        }
        int nextB = r;

        // count > x in this range
        int gaps = read(fFreq, nextB) - read(fFreq, prevB);
        assert(1 < pos && pos < n);
        // assert(nextB > pos && prevB < pos);

        // iterate over xs in this range
        int cnt = 1;
        update(fFreq, pos, +1);
        while (i+1 < (int)loc.size() && loc[i+1].first == x && loc[i+1].second < nextB) {
            ++i, ++cnt;
            update(fFreq, loc[i].second, +1);
        }

        // multiply answer by number of ways to put count in gaps
        // assert(gaps >= 1);
        ans = mult(ans, combi(gaps, cnt, true));
    }
    // assert(ans >= 1);
    cout << ans << endl;
    return 0;
}
